@@ -12,6 +12,7 @@ pub use self::external_memory_fd::ExternalMemoryFd;
 pub use self::external_semaphore_fd::ExternalSemaphoreFd;
 pub use self::get_memory_requirements2::GetMemoryRequirements2;
 pub use self::get_physical_device_properties2::GetPhysicalDeviceProperties2;
+pub use self::get_surface_capabilities2::GetSurfaceCapabilities2;
 pub use self::maintenance1::Maintenance1;
 pub use self::maintenance3::Maintenance3;
 pub use self::maintenance4::Maintenance4;
@@ -42,6 +43,7 @@ mod external_memory_fd;
 mod external_semaphore_fd;
 mod get_memory_requirements2;
 mod get_physical_device_properties2;
+mod get_surface_capabilities2;
 mod maintenance1;
 mod maintenance3;
 mod maintenance4;
